:root {
  /* light theme */
    --text-light: rgba(0, 0, 0, 0.87);
    --main-light: #fff;
    --secondary-light: rgb(247, 249, 252);
    --border-light: rgb(224, 224, 224);
    --path-light: #e0e4e7;
  /* dark theme */
    --main-dark: rgb(27, 38, 53);
    --text-dark:  rgba(255, 255, 255, 0.95);
    --secondary-dark: rgb(35, 48, 68);
    --border-dark: rgb(81, 81, 81);
    --path-dark: #4b5760;
}

body {
  --text: var(--text-light);
  --main: var(--main-light);
  --secondary: var(--secondary-light);
  --border: var(--border-light);
  --path: var(--path-light);
}

body.dark {
  --text: var(--text-dark);
  --main: var(--main-dark);
  --secondary: var(--secondary-dark);
  --border: var(--border-dark);
  --path: var(--path-dark);
}