@font-face {
  font-family: Arimo;
  src: url(/font/Arimo-Regular.woff2);
}

@font-face {
  font-family: ArimoBold;
  src: url(/font/Arimo-Bold.woff2);
}

@font-face {
  font-family: ArimoSemiBold;
  src: url(/font/Arimo-SemiBold.woff2);
}

* {
  font-family: Arimo;
  box-sizing: border-box;
}

a, .link {
  cursor: pointer;
  color: rgb(71, 130, 218);
  text-decoration: none;
}

a:hover {
  opacity: 0.7;
}

body {
  width: 100%;
  height: 100%;
  min-width: 1320px;
  margin: 0;
  display: flex;
  flex-direction: column;
  background-color: var(--main);
}

header {
  background-color: var(--secondary-dark);
  padding: 8px 0;
  display: flex;
  justify-content: space-between;
  align-items: center;
}

main {
  padding: 24px 0;
  flex: 1;
}

footer {
  min-height: 90px;
  background-color: rgb(35, 48, 68);
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  color: rgb(238, 238, 238);
}

footer > div {
  margin-bottom: 8px;
}

footer a:first-child {
  margin-right: 8px;
}

input[type=text] {
  width: 100%;
  background-color: var(--main);
  border: 0px;
  -webkit-tap-highlight-color: transparent;
  margin: 0px;
  color: var(--text);
  font-size: 13px;
  padding: 8px 8px;
  font-family: Arimo;
  font-weight: 400;
  border-radius: 4px;
  border: 1px solid rgba(0, 0, 0, 0.23);
  box-shadow: rgb(50 50 93 / 2%) 0px 2px 5px -1px, rgb(0 0 0 / 5%) 0px 1px 3px -1px;
  padding-right: 24px;
}

input[type=text]:disabled {
  opacity: 0.5;
}

input[type=text]::placeholder {
  color: #757575;
}

object {
  pointer-events: none;
}