/* ______DASHBOARD_______ */
.dashboard-section {
  padding: 43px;
  padding-top: 24px;
  margin: auto;
  margin-bottom: 64px;
  background-color: var(--secondary);
  border-radius: 6px;
}

.dashboard-section_header {
  display: flex;
  align-items: center;
  margin-bottom: 16px;
}

.dashboard-section-content {
  display: grid;
  grid-gap: 16px 16px;
}

.dashboard-section_header_title {
  font-family: 'ArimoSemiBold';
  color: var(--text);
  font-size: 1.3rem;
  margin: 0;
}

.dashboard-section_header_info {
  cursor: help;
  margin-left: 12px;
}

.item {
  height: 100%;
}

/* ______POPUP_______ */
.popup-content {
  box-shadow: 2px 2px 6px 0px rgba(50, 50, 50, 0.75);
  position: fixed;
  background-color: var(--main);
  z-index: 999;
  border: 1px solid var(--border);
  border-radius: 6px;
}

.popup-big {
  width: 600px;
}

.popup-small {
  width: 300px;
}

.popup-header {
  box-sizing: border-box;
  padding: 12px;
  font-weight: bold;
  color: var(--text);
  display: flex;
  justify-content: space-between;
  align-items: center;
  border-bottom: 1px solid var(--border);
  font-family: 'ArimoSemiBold';
}

.popup-body {
  max-height: 300px;
  overflow-y: scroll;
  width: 100%;
}

.popup-section {
  padding: 16px 8px;
  border-bottom: 1px solid var(--border);
  color: var(--text);
}

.popup-section:last-child {
  border-bottom: none;
}

.popup-content .table td, .popup-content .table th {
  border-color: var(--border);
  padding: 16px;
}

.popup-content .table th {
  border-bottom: 1px solid var(--border);
}

.popup-content .table tr:last-child th, .popup-content .table tr:last-child td {
  border-bottom: none;
}

.popup-content .table th {
  color: var(--text);
}

.popup-content .table td {
  color: var(--text);
}

/* ________TABLE________ */
.table {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0px;
}

.table tr {
  color: inherit;
  display: table-row;
  vertical-align: middle;
  outline: 0px;
}

.table thead {
  position: sticky;
  top: 0px;
  background: var(--main);
  box-shadow: inset 0 -1px 0 var(--border);
}

/* TODO remove duplicates */
.table thead tr th {
  font-family: ArimoSemiBold;
  font-size: 1rem;
  line-height: 1.39286rem;
  display: table-cell;
  vertical-align: inherit;
  text-align: left;
  padding: 16px;
  color: var(--text);
}

.table tbody {
  display: table-row-group;
}

.table tbody tr td {
  font-family: Arimo;
  font-size: 1rem;
  line-height: 1.43;
  display: table-cell;
  vertical-align: inherit;
  border-bottom: 1px solid var(--border);
  text-align: left;
  padding: 16px;
  color: var(--text);
}

.chip {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 6px;
  padding: 4px 12px;
  width: fit-content;
}

.total {
  fill: var(--text);
}

.logo {
  font-family: ArimoBold;
  font-size: 1.8rem;
  display: flex;
  align-items: center;
  margin-left: 32px;
  font-weight: 700;
  color: rgb(238, 238, 238);
}

.color-switch {
  margin-right: 32px;
  cursor: pointer;
  user-select: none;
}

.color-switch svg {
  width: 18px;
  height: 18px;
  fill: white;
}

.dark .color-switch {
  transform: rotate(180deg);
}

.tick text {
  fill: var(--text);
  font-size: 0.8rem; 
}

.axis path, .axis line {
  stroke: var(--border)
}

.filters {
  display: flex;
  gap: 16px;
  position: absolute;
  top: -48px;
  right: 8px;
}

.warning {
  color: rgb(239, 83, 80);
}

.good {
  color: rgb(76, 175, 80);
}

.loading {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.05);
  left: 0;
  top: 0;
  border-radius: 6px;
}

.loading object {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

.indicator {
  cursor: pointer;
  width: 34px;
  height: 34px;
}

.button {
  background: rgb(64, 122, 214);
  border-radius: 8px;
}

.error {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  color: red;
}