npm-dashboard {
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  align-items: flex-start;
  padding: 0 32px;
  box-sizing: content-box;
}

dashboard-widget {
  position: relative;
  background-color: var(--main);
  border-radius: 6px;
  box-shadow: rgb(50 50 93 / 2%) 0px 2px 5px -1px, rgb(0 0 0 / 5%) 0px 1px 3px -1px;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
}

dashboard-widget h2 {
  font-size: 1rem;
  font-weight: 500;
  line-height: 1.25;
  font-family: Arimo;
  color: var(--text);
  height: 55px;
  position: absolute;
  padding: 0 16px;
  top: 0;
  margin: 0;
  display: flex;
  align-items: center;
}

popups-root {
  position: absolute;
  top: 0;
  left: 0;
}

updates-table, vulnerabilities-table, issues-table, deprecated-table {
  overflow-y: scroll;
  border-radius: 6px;
}

.total {
  fill: #5F7278;
}

dependencies-list {
  position: relative;
  display: flex;
  flex-direction: column;
}

dependencies-list .dependencies-list_list {
  overflow: auto;
  display: block;
}

dependency-item {
  border-top: 1px solid var(--border);
  display: block;
  padding-bottom: 2px;
}

dependency-item:only-child {
  border-bottom: 1px solid var(--border);
}

dependency-item:first-child {
  border-top: none;
}

dependency-item .dependency-item_description {
  margin-top: 8px;
  margin-left: 8px;
  color: var(--text);
  opacity: 0.6;
  font-size: 0.9rem;
  max-width: 50%;
}

dependency-item .dependency-item_data {
  padding: 16px 8px;
}

dependency-item .dependency-item_name-container {
  display: flex;
  justify-content: flex-start;
  align-items: center;
}

dependency-item .dependency-item_name {
  color: var(--text);
  font-family: ArimoSemiBold;
  font-size: 1.2rem;
  font-weight: 400;
  margin-left: 8px;
}

dependency-item .dependency-item_versions-tags {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  margin-top: 16px;
}

dependency-item .dependency-item_versions-list_trigger {
  cursor: pointer;
  color: var(--text);
  padding: 8px;
  display: flex;
  justify-content: center;
  align-items: center;
  border-top: 1px solid var(--border);
}

dependency-item .dependency-item_versions-list_trigger_icon {
  margin-right: 8px;
}

dependency-item .dependency-item_versions-list-opened .dependency-item_versions-list_trigger_icon {
  transform: rotate(90deg);
}

dependency-item .dependency-item_versions-list-wrapper {
  padding: 0 8px;
  background: var(--main);
}

dependency-item .dependency-item_header {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

dependency-item .dependency-item_indicators {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  gap: 16px;
  margin-right: 8px;
}

dependency-item .dependency-item_indicators_vulnerable, dependency-item .dependency-item_indicators_update {
  display: flex;
  justify-content: center;
  align-items: center;
  cursor: pointer;
}

version-item {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  border-bottom: 2px solid var(--border);
  padding: 16px 12px;
}

version-item:last-child {
  border-bottom: none;
}

version-item .version-item_name {
  font-size: 1.1rem;
  color: var(--text);
  margin-right: 8px;
  opacity: 0.6;
}

dependency-version {
  padding: 8px;
  font-size: 1rem;
  color: var(--main-light);
  font-family: ArimoBold;
  letter-spacing: 0.015em;
  background: rgb(55, 111, 208);
  border-radius: 6px;
  margin-left: 8px;
}

dependency-info {
  cursor: pointer;
  display: flex;
}

dependency-filter {
  display: block;
  position: relative;
  width: 300px;
}

dependency-filter ul, custom-select ul {
  width: 100%;
  position: absolute;
  z-index: 999;
  margin-top: 4px;
  background-color: var(--secondary);
  color: var(--text);
  border-radius: 4px;
  padding: 8px 0px;
  box-shadow: rgb(50 50 93 / 2%) 0px 2px 5px -1px, rgb(0 0 0 / 5%) 0px 1px 3px -1px;
}

dependency-filter li, custom-select li {
  font-size: 13px;
  font-family: Arimo;
  cursor: pointer;
  font-weight: 400;
  line-height: 1.5;
  padding: 6px 16px;
  box-sizing: border-box;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
}
dependency-filter li:hover, custom-select li:hover {
  background-color: rgba(0, 0, 0, 0.04);
}

dependency-filter .dependency-filter_clear {
  width: 10px;
  height: 10px;
  cursor: pointer;
  position: absolute;
  top: 12px;
  right: 8px;
}

custom-select {
  display: block;
  position: relative;
  width: 150px;
}

custom-select .custom-select_trigger {
  display: flex;
  justify-content: space-between;
  align-items: center;
  cursor: pointer;
  width: 100%;
  background-color: var(--main);
  border: 0px;
  margin: 0px;
  color: var(--text);
  font-size: 13px;
  padding: 8px 8px;
  font-weight: 400;
  border-radius: 4px;
  border: 1px solid rgba(0, 0, 0, 0.23);
  box-shadow: rgb(50 50 93 / 2%) 0px 2px 5px -1px, rgb(0 0 0 / 5%) 0px 1px 3px -1px;
}

custom-select .custom-select_trigger span:first-child {
  margin-right: 16px;
  font-family: Arimo;
}

custom-select .custom-select_trigger .unselected {
  color: #757575;
}

package-data, basic-info {
  display: flex;
  align-items: flex-start;
  justify-content: flex-start;
  flex-direction: column;
}

package-data .filters, basic-info .filters {
  display: none;
}

package-data .package-data_section, basic-info .basic-info_section {
  font-size: 1rem;
  color: var(--text);
  padding: 16px;
  border-bottom: 1px solid var(--border);
  width: 100%;
}

package-data .package-data_section:last-child, basic-info .basic-info_section:last-child {
  border-bottom: none;
}

package-data .package-data_section_title, basic-info .basic-info_section_title {
  font-size: 1rem;
  opacity: 0.7;
  margin-bottom: 16px;
}

basic-info .basic-info_section_without_indicator span {
  color: var(--text);
}

basic-info .basic-info_section {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

section-info-popup .popup-content {
  max-width: 500px;
}

section-info-popup .popup-content div {
  margin-bottom: 8px;
}

section-info-popup .popup-content div:last-child {
  margin-bottom: 0;
}