#dependencies-limitation {
  display: flex;
  justify-content: space-between;
  align-items: center;
  width: 200px;
}

#dependencies-info {
  position: absolute;
  bottom: 10px;
  right: 20px;
  display: flex;
  justify-content: center;
  align-items: center;
}

#dependencies-info > div {
  padding: 0 16px;
  border-right: 1px solid black;
}

#dependencies-info > div:last-child {
  border-right: none;
}

#dependencies-filter {
  position: absolute;
  z-index: 2;
  top: 15px;
  right: 8px;
}

#dependencies-filter > input {
  margin-right: 8px;
  width: 210px
}

#layout-message {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}

#center-icon {
  width: 25px;
  height: 25px;
  cursor: pointer;
}